==> compass-service-0.1.102-sources.jar: com/xforceplus/compass/controller/MiroResultController.java <==
package com.xforceplus.compass.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.compass.entity.MiroResult;
import com.xforceplus.compass.service.IMiroResultService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-08-08
 */
@RestController
public class MiroResultController {

  @Autowired
  private IMiroResultService miroResultServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param miroResult ${table.comment}
   * @return
   */
  @GetMapping("/miroresults" )
  public XfR getMiroResults(XfPage page, MiroResult miroResult) {
    return XfR.ok(miroResultServiceImpl.page(page, Wrappers.query(miroResult)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/miroresults/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(miroResultServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param miroResult ${table.comment}
   * @return XfR
   */
  @PostMapping("/miroresults")
  public XfR save(@RequestBody MiroResult miroResult) {
     return XfR.ok(miroResultServiceImpl.save(miroResult));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param miroResult ${table.comment}
   * @return XfR
   */
  @PutMapping("/miroresults/{id}")
  public XfR putUpdate(@RequestBody MiroResult miroResult,@PathVariable Long id) {
      miroResult.setId(id);
      return XfR.ok(miroResultServiceImpl.updateById(miroResult));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param miroResult ${table.comment}
   * @return XfR
   */
  @PatchMapping("/miroresults/{id}")
  public XfR patchUpdate(@RequestBody MiroResult miroResult,@PathVariable Long id) {
      MiroResult upmiroResult = miroResultServiceImpl.getById(id);
      if(upmiroResult != null){
        upmiroResult = ObjectCopyUtils.copyProperties(miroResult,upmiroResult,true);
      }
      return XfR.ok(miroResultServiceImpl.updateById(upmiroResult));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/miroresults/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(miroResultServiceImpl.removeById(id));
  }

  @PostMapping("/miroresults/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "miro_result");
     params.put("request", condition);

     return XfR.ok(miroResultServiceImpl.querys(params));
  }

}

==> compass-service-0.1.182-sources.jar: com/xforceplus/compass/controller/MiroResultController.java <==
package com.xforceplus.compass.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.compass.entity.MiroResult;
import com.xforceplus.compass.service.IMiroResultService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;

/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2025-05-19
 */
@RestController
public class MiroResultController {

  @Autowired
  private IMiroResultService miroResultServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param miroResult ${table.comment}
   * @return
   */
  @GetMapping("/miroresults" )
  public XfR getMiroResults(XfPage page, MiroResult miroResult) {
    return XfR.ok(miroResultServiceImpl.page(page, Wrappers.query(miroResult)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/miroresults/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(miroResultServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param miroResult ${table.comment}
   * @return XfR
   */
  @PostMapping("/miroresults")
  public XfR save(@RequestBody MiroResult miroResult) {
     return XfR.ok(miroResultServiceImpl.save(miroResult));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param miroResult ${table.comment}
   * @return XfR
   */
  @PutMapping("/miroresults/{id}")
  public XfR putUpdate(@RequestBody MiroResult miroResult,@PathVariable Long id) {
      miroResult.setId(id);
      return XfR.ok(miroResultServiceImpl.updateById(miroResult));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param miroResult ${table.comment}
   * @return XfR
   */
  @PatchMapping("/miroresults/{id}")
  public XfR patchUpdate(@RequestBody MiroResult miroResult,@PathVariable Long id) {
      MiroResult upmiroResult = miroResultServiceImpl.getById(id);
      if(upmiroResult != null){
        upmiroResult = ObjectCopyUtils.copyProperties(miroResult,upmiroResult,true);
      }
      return XfR.ok(miroResultServiceImpl.updateById(upmiroResult));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/miroresults/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(miroResultServiceImpl.removeById(id));
  }

  @PostMapping("/miroresults/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "miro_result");
     params.put("request", condition);

     return XfR.ok(miroResultServiceImpl.querys(params));
  }

}
